Index: trunk/ppImage/src/ppImageParseCamera.c
===================================================================
--- trunk/ppImage/src/ppImageParseCamera.c	(revision 43038)
+++ trunk/ppImage/src/ppImageParseCamera.c	(revision 43049)
@@ -124,7 +124,7 @@
     if (options->doMaskBadOverscan) {
 	// if the file has been specified on the command-line (-valid-overscan file), then the file
-	// is identified by the VALID.OVERSCAN entry in config->arguments.  otherwise, load from the
-	// detrend system as type VALID.OVERSCAN
-	if (!ppImageDefineFile(config, input->fpa, "PPIMAGE.VALID.OVERSCAN", "VALID.OVERSCAN",
+	// is identified by the VALID_OVERSCAN entry in config->arguments.  otherwise, load from the
+	// detrend system as type VALID_OVERSCAN
+	if (!ppImageDefineFile(config, input->fpa, "PPIMAGE.VALID.OVERSCAN", "VALID_OVERSCAN",
 			       PM_FPA_FILE_VALID_OVERSCAN, PM_DETREND_TYPE_VALID_OVERSCAN)) {
 	    psError(PS_ERR_IO, false, "Can't find a new non-linearity correction source");
